==> pleiades_1.2.2-src.zip: src/jp/sourceforge/mergedoc/pleiades/aspect/PleiadesOption.java <==
/*
 * Copyright (c) 2005- Shinji Kashihara.
 * All rights reserved. This program are made available under
 * the terms of the Eclipse Public License v1.0 which accompanies
 * this distribution, and is available at epl-v10.html.
 */
package jp.sourceforge.mergedoc.pleiades.aspect;

import jp.sourceforge.mergedoc.pleiades.log.Logger;
import jp.sourceforge.mergedoc.pleiades.resource.TranslationNotFoundProperties;

import org.apache.commons.lang.StringUtils;

/**
 * Pleiades NIvVłB
 * <p>
 * @author cypher256
 */
public class PleiadesOption {
	
	/** Eclipse  -clean IvV */
	private boolean isClean;
	
	/** ftHgEXvbVʕ\IvV */
	private final boolean isDefaultSplash;
	
	/** j[jbN\IvV */
	private final boolean isNoMnemonic;
	
	/** OEx */
	private String logLevel;
	
	/**
	 * NIvV\z܂B
	 * <p>
	 * @param agentArg G[WFgN
	 */
	PleiadesOption(String agentArg) {
		
		String arg = (agentArg == null) ? "" : "," + agentArg.replace(" ", "") + ",";
		
		isDefaultSplash = arg.contains(",default.splash,");
		isNoMnemonic = arg.contains(",no.mnemonic,");
		
		// ɖ󂪖ꍇ̃Oo͂邩
		boolean isEnabledNotFoundLog = arg.contains(",enabled.not.found.log,");
		if (isEnabledNotFoundLog) {
			System.setProperty(TranslationNotFoundProperties.NOT_FOUND_PROPERTIES_ENABELD, "true");
		}
		
		// OEx̎擾
		if (arg.contains("log.level=")) {
			logLevel = arg.replaceFirst("^.*?log\\.level=", "").replaceFirst(",.*$", "");
			try {
				Logger.Level.valueOf(logLevel.toUpperCase());
			} catch (IllegalArgumentException e) {
				throw new IllegalArgumentException(
					"NIvV log.level ̒l [" + logLevel + "] słB" +
					StringUtils.join(Logger.Level.values(), ",") +
					" ̂ꂩłKv܂B");
			}
		} else {
			logLevel = Logger.Level.INFO.toString();
		}
	}
	
	/**
	 * Eclipse  -clean IvVZbg܂B
	 * <p>
	 * @param isClean N -clean w肳Ăꍇ true
	 */
	public void setClean(boolean isClean) {
		this.isClean = isClean;
	}
	
	/**
	 * Eclipse  -clean IvV擾܂B
	 * <p>
	 * @return N -clean w肳Ăꍇ true
	 */
	public boolean isClean() {
		return isClean;
	}
	
	/**
	 * Eclipse ̃ftHgEXvbVʂgp邩肵܂B
	 * <p>
	 * @return gpꍇ true
	 */
	public boolean isDefaultSplash() {
		return isDefaultSplash;
	}
	
	/**
	 * j[jbN\Ȃ肵܂B
	 * <p>
	 * @return gpȂꍇ true
	 */
	public boolean isNoMnemonic() {
		return isNoMnemonic;
	}
	
	/**
	 * OEx擾܂B
	 * <p>
	 * @return OEx
	 */
	public String getLogLevel() {
		return logLevel;
	}
}

==> pleiades_1.2.3-src.zip: src/jp/sourceforge/mergedoc/pleiades/aspect/PleiadesOption.java <==
/*
 * Copyright (c) 2005- Shinji Kashihara.
 * All rights reserved. This program are made available under
 * the terms of the Eclipse Public License v1.0 which accompanies
 * this distribution, and is available at epl-v10.html.
 */
package jp.sourceforge.mergedoc.pleiades.aspect;

import jp.sourceforge.mergedoc.pleiades.log.Logger;
import jp.sourceforge.mergedoc.pleiades.resource.TranslationNotFoundProperties;

import org.apache.commons.lang.StringUtils;

/**
 * Pleiades 起動オプションです。
 * <p>
 * @author cypher256
 */
public class PleiadesOption {
	
	/** Eclipse の -clean オプション */
	private boolean isClean;
	
	/** デフォルト・スプラッシュ画面表示オプション */
	private final boolean isDefaultSplash;
	
	/** ニーモニック表示オプション */
	private final boolean isNoMnemonic;
	
	/** ログ・レベル */
	private String logLevel;
	
	/**
	 * 起動オプションを構築します。
	 * <p>
	 * @param agentArg エージェント起動引数
	 */
	PleiadesOption(String agentArg) {
		
		String arg = (agentArg == null) ? "" : "," + agentArg.replace(" ", "") + ",";
		
		isDefaultSplash = arg.contains(",default.splash,");
		isNoMnemonic = arg.contains(",no.mnemonic,");
		
		// 辞書に訳が無い場合のログ出力をするか
		boolean isEnabledNotFoundLog = arg.contains(",enabled.not.found.log,");
		if (isEnabledNotFoundLog) {
			System.setProperty(TranslationNotFoundProperties.NOT_FOUND_PROPERTIES_ENABELD, "true");
		}
		
		// ログ・レベルの取得
		if (arg.contains("log.level=")) {
			logLevel = arg.replaceFirst("^.*?log\\.level=", "").replaceFirst(",.*$", "");
			try {
				Logger.Level.valueOf(logLevel.toUpperCase());
			} catch (IllegalArgumentException e) {
				throw new IllegalArgumentException(
					"起動オプション log.level の値 [" + logLevel + "] が不正です。" +
					StringUtils.join(Logger.Level.values(), ",") +
					" のいずれかである必要があります。");
			}
		} else {
			logLevel = Logger.Level.INFO.toString();
		}
	}
	
	/**
	 * Eclipse の -clean オプションをセットします。
	 * <p>
	 * @param isClean 起動時に -clean が指定されている場合は true
	 */
	public void setClean(boolean isClean) {
		this.isClean = isClean;
	}
	
	/**
	 * Eclipse の -clean オプションを取得します。
	 * <p>
	 * @return 起動時に -clean が指定されている場合は true
	 */
	public boolean isClean() {
		return isClean;
	}
	
	/**
	 * Eclipse のデフォルト・スプラッシュ画面を使用するか判定します。
	 * <p>
	 * @return 使用する場合は true
	 */
	public boolean isDefaultSplash() {
		return isDefaultSplash;
	}
	
	/**
	 * ニーモニックを表示しないか判定します。
	 * <p>
	 * @return 使用しない場合は true
	 */
	public boolean isNoMnemonic() {
		return isNoMnemonic;
	}
	
	/**
	 * ログ・レベルを取得します。
	 * <p>
	 * @return ログ・レベル
	 */
	public String getLogLevel() {
		return logLevel;
	}
}
